@@ -17,13 +17,18 @@ import stan.common
 import stan.fit
 import stan.plugins
 
-Data = Dict[str, Union[int, float, Sequence[Union[int, float]], np.ndarray]]
+Data = Dict[str, Union[int, float, Sequence[Union[int, float]]]]
 
 
 class DataJSONEncoder(json.JSONEncoder):
     def default(self, obj):
+        # numpy.ndarray is *unofficially* supported as there is no easy way to
+        # construct tabular data using the Python standard library.
         if isinstance(obj, np.ndarray):
             return obj.tolist()
+        # unofficially support np.int64, np.int32, etc.
+        if hasattr(obj, "dtype") and np.issubdtype(obj.dtype, np.integer):
+            return int(obj)
         return json.JSONEncoder.default(self, obj)
 
 
